@@ -1,5 +1,5 @@
 package Getopt::EX::Colormap;
-use version; our $VERSION = version->declare("v1.23.1");
+use version; our $VERSION = version->declare("v1.23.2");
 
 use v5.14;
 use warnings;
@@ -443,10 +443,13 @@ sub colortable12 {
 	);
 }
 
+# use charnames ':full';
+
 sub colortable24 {
     colortableN(
 	step   => 24,
-	string => "\N{UPPER HALF BLOCK}",
+#	string => "\N{UPPER HALF BLOCK}",
+	string => "\N{U+2580}",
 	shift  => 1,
 	x => 1, y => 2, z => 4,
 	@_
